#!/usr/bin/env python3

import os
import subprocess
import logging

# Konfiguration
LOGDIR = "/tmp"
LOGFILE = os.path.join(LOGDIR, "kitte888_oscam_check.log")

# Logging einrichten
logging.basicConfig(filename=LOGFILE, level=logging.INFO, format='%(asctime)s - %(message)s')
logging.info("**************************** START *******************************")

def check_oscam():
    try:
        # Suche nach laufenden Prozessen, die "oscam" enthalten
        result = subprocess.run(
            ["ps", "aux"], stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True
        )
        # Filtere die Ausgabe nach "oscam", ignoriere den "grep"-Prozess
        process_lines = [
            line for line in result.stdout.splitlines() if "oscam" in line and "grep" not in line
        ]

        if process_lines:
            for process_info in process_lines:
                print("Oscam läuft. Details:")
                print(process_info)
                logging.info(f"Oscam läuft. Details: {process_info}")

                # Extrahiere den Oscam-Namen (nach "/usr/bin/")
                parts = process_info.split()
                logging.info(f"parts: {parts}")
               # Finde den Pfad zur Oscam-Binary (letztes Element, das mit '/' beginnt)
                executable = next((part for part in parts if part.startswith("/")), None)

                if executable:
                    # Extrahiere nur den Dateinamen
                    oscam_name = os.path.basename(executable)  # Nur der Name der ausführbaren Datei
                    print(f"Gefundener Oscam-Name: {oscam_name}")
                    logging.info(f"Gefundener Oscam-Name: {oscam_name}")

                     # Optional: Prozess stoppen
                    stop_process(oscam_name)

                else:
                    print("Kein gültiger Oscam-Pfad gefunden.")
                    logging.info("Kein gültiger Oscam-Pfad gefunden.")

        else:
            print("Oscam läuft nicht.")
            logging.info("Oscam läuft nicht.")
    except Exception as e:
        print(f"Fehler beim Überpruefen von Oscam: {e}")
        logging.error(f"Fehler beim Überpruefen von Oscam: {e}")

def stop_process(oscam_name):
    try:
        # Stoppe den Prozess mit killall
        print(f"Beende Oscam-Prozess: {oscam_name}")
        logging.info(f"Beende Oscam-Prozess: {oscam_name}")
        subprocess.run(["killall", oscam_name], check=True)
        print(f"Oscam {oscam_name} wurde gestoppt.")
        logging.info(f"Oscam {oscam_name} wurde gestoppt.")
    except subprocess.CalledProcessError as e:
        print(f"Fehler beim Stoppen des Oscam-Prozesses: {e}")
        logging.error(f"Fehler beim Stoppen des Oscam-Prozesses: {e}")

if __name__ == "__main__":
    check_oscam()


# in console aufrufen oder aus einer shell
# /usr/bin/check_cam.sh