#!/usr/bin/env python3

import os
import sys
import time
import logging
from urllib import request
from urllib.error import URLError

# Konfiguration
BOXIP = "http://localhost"
LOGDIR = "/tmp"
LOGFILE = os.path.join(LOGDIR, "kitte888_message.log")
ANSWER_FILE = "/tmp/oscam_answer.txt"

# Logging einrichten
logging.basicConfig(filename=LOGFILE, level=logging.INFO, format='%(asctime)s - %(message)s')
logging.info("**************************** START *******************************")

# Funktion zum Senden von Nachrichten
def show_message(message, fenstertype, fensterzeit):
    logging.info(f"message: {message}")
    logging.info(f"type: {fenstertype}")
    logging.info(f"timeout: {fensterzeit}")

    try:
        # Nachricht an Enigma2 senden
        url = f"{BOXIP}/web/message?text={message.replace(' ', '+')}&type={fenstertype}&timeout={fensterzeit}"
        logging.info(f"Nachricht senden url: {url}")
        response = request.urlopen(url)
        logging.info(f"Nachricht gesendet: {message}")

        # Auf Antwort warten (bei type=0 erwartet Enigma2 eine Benutzeraktion)
        if fenstertype == "0":
            logging.info("Warte auf Benutzerantwort...")
            time.sleep(int(fensterzeit))  # Warte entsprechend Timeout
            
            # Antwort von Enigma2 abrufen
            # Beispielhafte Abfrage von Enigma2 API (ersetze mit korrektem Endpoint)
            answer_url = f"{BOXIP}/web/messageanswer"
            try:
                answer_response = request.urlopen(answer_url)
                answer = answer_response.read().decode().strip()
                logging.info(f"Antwort von Enigma2: {answer}")
            except URLError as e:
                logging.error(f"Fehler beim Abrufen der Antwort: {e}")
                answer = "no"  # Standardantwort bei Fehler

            # Antwort speichern
            with open(ANSWER_FILE, "w") as answer_file:
                answer_file.write(answer)
    except Exception as e:
        logging.error(f"Fehler beim Senden der Nachricht: {e}")
        with open(ANSWER_FILE, "w") as answer_file:
            answer_file.write("no")  # Standardantwort bei Fehler

if __name__ == "__main__":
    if len(sys.argv) != 4:
        logging.error("Usage: python script.py <message> <type> <timeout>")
        sys.exit(1)

    # Argumente auslesen
    MESSAGE = sys.argv[1]
    msg_type = sys.argv[2]
    TIMEOUT = sys.argv[3]

    # Nachricht senden
    show_message(MESSAGE, msg_type, TIMEOUT)
    sys.exit(0)  # Erfolgreich beendet

    # Der Rest des Codes wird nicht erreicht, da wir das Skript hier beenden
# so testen ob das script geht in der console

#wget  -O -q  "http://localhost/web/message?text=POSTINSTALL&type=1&timeout=5"


#  /usr/bin/message_box.sh "Deine Nachricht hier" 1 5

#  python $MESSAGE_PATH "Möchten Sie fortfahren?" 1 5 >> $LOGFILE 1>&1

# so dann aus oscam 

#system("python3 /usr/bin//message_box.sh \"Deine Nachricht hier\");

#Boxen folgende Bedeutungen für type:

#type=0: Frage mit einer Ja/Nein-Auswahl.
#type=1: Information
#type=2: Fehler- oder Warnmeldung.
#type=3: Fehler